@@ -21,7 +21,7 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #define QLIPPERPREFERENCES_H
 
 #include <QtCore/QSettings>
-
+#include <QDataStream>
 #include "qlipperitem.h"
 
 
@@ -37,14 +37,19 @@ public:
     void saveDynamicItems(QList<QlipperItem> list);
 
     bool trim();
-    int displaySize();
-    QString shortcut();
-    int historyCount();
-    bool platformExtensions();
+    int displaySize() const;
+    QString shortcut() const;
+    int historyCount() const;
+    bool platformExtensions() const;
+    bool synchronizePSE() const;
+    bool clearItemsOnExit() const;
+    bool synchronizeHistory() const;
 
-    bool networkSend();
-    bool networkReceive();
-    int networkPort();
+    bool networkSend() const;
+    bool networkReceive() const;
+    int networkPort() const;
+
+    bool shouldSynchronizeClipboards() const;
 
 private:
     QlipperPreferences();
